Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Connect Customer Profiles.

Actions, resources, and condition keys for Amazon Connect Customer Profiles - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Connect Customer Profiles

Amazon Connect Customer Profiles (service prefix: `profile` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Connect Customer Profiles
- Resource types defined by Amazon Connect Customer Profiles
- Condition keys for Amazon Connect Customer Profiles

## Actions defined by Amazon Connect Customer Profiles

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddProfileKey | Grants permission to add a profile key | Write | domains* |  |
CreateDomain | Grants permission to create a Domain | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateIntegrationWorkflow | Grants permission to create an integration workflow in a domain | Write | domains* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateProfile | Grants permission to create a profile in the domain | Write | domains* |  |
DeleteDomain | Grants permission to delete a Domain | Write | domains* |  |
DeleteIntegration | Grants permission to delete a integration in a domain | Write | domains* |  |
integrations* |  |
DeleteProfile | Grants permission to delete a profile | Write | domains* |  |
DeleteProfileKey | Grants permission to delete a profile key | Write | domains* |  |
DeleteProfileObject | Grants permission to delete a profile object | Write | domains* |  |
object-types* |  |
DeleteProfileObjectType | Grants permission to delete a specific profile object type in the domain | Write | domains* |  |
object-types* |  |
DeleteWorkflow | Grants permission to delete a workflow in a domain | Write | domains* |  |
GetAutoMergingPreview | Grants permission to get a preview of auto merging in a domain | Read | domains* |  |
GetDomain | Grants permission to get a specific domain in an account | Read | domains* |  |
GetIdentityResolutionJob | Grants permission to get an identity resolution job in a domain | Read | domains* |  |
GetIntegration | Grants permission to get a specific integrations in a domain | Read | domains* |  |
integrations* |  |
GetMatches | Grants permission to get profile matches in a domain | List | domains* |  |
GetProfileObjectType | Grants permission to get a specific profile object type in the domain | Read | domains* |  |
object-types* |  |
GetProfileObjectTypeTemplate | Grants permission to get a specific object type template | Read |  |  |
GetWorkflow | Grants permission to get workflow details in a domain | Read | domains* |  |
GetWorkflowSteps | Grants permission to get workflow step details in a domain | Read | domains* |  |
ListAccountIntegrations | Grants permission to list all the integrations in the account | List |  |  |
ListDomains | Grants permission to list all the domains in an account | List |  |  |
ListIdentityResolutionJobs | Grants permission to list identity resolution jobs in a domain | List | domains* |  |
ListIntegrations | Grants permission to list all the integrations in a specific domain | List | domains* |  |
ListProfileObjectTypeTemplates | Grants permission to list all the profile object type templates in the account | List |  |  |
ListProfileObjectTypes | Grants permission to list all the profile object types in the domain | List | domains* |  |
ListProfileObjects | Grants permission to list all the profile objects for a profile | List | domains* |  |
object-types* |  |
ListTagsForResource | Grants permission to list tags for a resource | Read |  |  |
ListWorkflows | Grants permission to list all the workflows in a specific domain | List | domains* |  |
MergeProfiles | Grants permission to merge profiles in a domain | Write | domains* |  |
PutIntegration | Grants permission to put a integration in a domain | Write | domains* |  |
integrations* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PutProfileObject | Grants permission to put an object for a profile | Write | domains* |  |
object-types* |  |
PutProfileObjectType | Grants permission to put a specific profile object type in the domain | Write | domains* |  |
object-types* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
SearchProfiles | Grants permission to search for profiles in a domain | Read | domains* |  |
TagResource | Grants permission to adds tags to a resource | Tagging |  | aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove tags from a resource | Tagging |  | aws:RequestTag/${TagKey} aws:TagKeys |
UpdateDomain | Grants permission to update a Domain | Write | domains* |  |
UpdateProfile | Grants permission to update a profile in the domain | Write | domains* |  |

## Resource types defined by Amazon Connect Customer Profiles

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
domains | `arn:$ { Partition}:profile:$ { Region}:$ { Account}:domains/$ { DomainName}` | aws:ResourceTag/${TagKey}
object-types | `arn:$ { Partition}:profile:$ { Region}:$ { Account}:domains/$ { DomainName}/object-types/$ { ObjectTypeName}` | aws:ResourceTag/${TagKey}
integrations | `arn:$ { Partition}:profile:$ { Region}:$ { Account}:domains/$ { DomainName}/integrations/$ { Uri}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Connect Customer Profiles

Amazon Connect Customer Profiles defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a key that is present in the request the user makes to the customer profile service | String
aws:ResourceTag/${TagKey} | Filters access by a tag key and value pair | String
aws:TagKeys | Filters access by the list of all the tag key names present in the request the user makes to the customer profile service | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.